==> plantuml-libs-7.1.0.tgz: package/distribution/material-4/Navigation/SubdirectoryArrowLeft.md <==
# SubdirectoryArrowLeft


```text
material-4/Navigation/SubdirectoryArrowLeft
```

```text
include('material-4/Navigation/SubdirectoryArrowLeft')
```



| Illustration | SubdirectoryArrowLeft |
| :---: | :---: |
| ![illustration for Illustration](../../material-4/Navigation/SubdirectoryArrowLeft.png) | ![illustration for SubdirectoryArrowLeft](../../material-4/Navigation/SubdirectoryArrowLeft.Local.png) |




## SubdirectoryArrowLeft

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('material-4/bootstrap')

' loads the Item which embeds the element SubdirectoryArrowLeft
include('material-4/Navigation/SubdirectoryArrowLeft')

' renders the element
SubdirectoryArrowLeft('SubdirectoryArrowLeft', 'Subdirectory Arrow Left', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('material-4/bootstrap')

' loads the Item which embeds the element SubdirectoryArrowLeft
include('material-4/Navigation/SubdirectoryArrowLeft')

' renders the element
SubdirectoryArrowLeft('SubdirectoryArrowLeft', 'Subdirectory Arrow Left', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.2.0.tgz: package/distribution/material-4/Navigation/SubdirectoryArrowLeft.md <==
# SubdirectoryArrowLeft


```text
material-4/Navigation/SubdirectoryArrowLeft
```

```text
include('material-4/Navigation/SubdirectoryArrowLeft')
```



| Illustration | SubdirectoryArrowLeft |
| :---: | :---: |
| ![illustration for Illustration](../../material-4/Navigation/SubdirectoryArrowLeft.png) | ![illustration for SubdirectoryArrowLeft](../../material-4/Navigation/SubdirectoryArrowLeft.Local.png) |




## SubdirectoryArrowLeft

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('material-4/bootstrap')

' loads the Item which embeds the element SubdirectoryArrowLeft
include('material-4/Navigation/SubdirectoryArrowLeft')

' renders the element
SubdirectoryArrowLeft('SubdirectoryArrowLeft', 'Subdirectory Arrow Left', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('material-4/bootstrap')

' loads the Item which embeds the element SubdirectoryArrowLeft
include('material-4/Navigation/SubdirectoryArrowLeft')

' renders the element
SubdirectoryArrowLeft('SubdirectoryArrowLeft', 'Subdirectory Arrow Left', 'an optional tech label', 'an optional description')
@enduml
```
